==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0/doc/fsdk/html/namespacefsdk.js <==
var namespacefsdk =
[
    [ "BaseDetection", "structfsdk_1_1_base_detection.html", "structfsdk_1_1_base_detection" ],
    [ "BaseRect", "structfsdk_1_1_base_rect.html", "structfsdk_1_1_base_rect" ],
    [ "ErrorTraits", "structfsdk_1_1_error_traits.html", null ],
    [ "ErrorTraits< FSDKError >", "structfsdk_1_1_error_traits_3_01_f_s_d_k_error_01_4.html", null ],
    [ "ErrorTraits< FutureError >", "structfsdk_1_1_error_traits_3_01_future_error_01_4.html", null ],
    [ "ErrorTraits< IDescriptorBatch::Error >", "structfsdk_1_1_error_traits_3_01_i_descriptor_batch_1_1_error_01_4.html", null ],
    [ "ErrorTraits< Image::Error >", "structfsdk_1_1_error_traits_3_01_image_1_1_error_01_4.html", null ],
    [ "ErrorTraits< ISerializableObject::Error >", "structfsdk_1_1_error_traits_3_01_i_serializable_object_1_1_error_01_4.html", null ],
    [ "ErrorTraits< ISettingsProvider::Error >", "structfsdk_1_1_error_traits_3_01_i_settings_provider_1_1_error_01_4.html", null ],
    [ "ErrorTraits< MultiError< E0, E1 > >", "structfsdk_1_1_error_traits_3_01_multi_error_3_01_e0_00_01_e1_01_4_01_4.html", "structfsdk_1_1_error_traits_3_01_multi_error_3_01_e0_00_01_e1_01_4_01_4" ],
    [ "ErrorTraits< PromiseError >", "structfsdk_1_1_error_traits_3_01_promise_error_01_4.html", null ],
    [ "EyeCropper", "structfsdk_1_1_eye_cropper.html", "structfsdk_1_1_eye_cropper" ],
    [ "EyesEstimation", "structfsdk_1_1_eyes_estimation.html", "structfsdk_1_1_eyes_estimation" ],
    [ "Face", "structfsdk_1_1_face.html", "structfsdk_1_1_face" ],
    [ "Format", "structfsdk_1_1_format.html", "structfsdk_1_1_format" ],
    [ "FunctionDetectionComparer", "classfsdk_1_1_function_detection_comparer.html", "classfsdk_1_1_function_detection_comparer" ],
    [ "Future", "classfsdk_1_1_future.html", "classfsdk_1_1_future" ],
    [ "HeadPoseEstimation", "structfsdk_1_1_head_pose_estimation.html", "structfsdk_1_1_head_pose_estimation" ],
    [ "Human", "structfsdk_1_1_human.html", "structfsdk_1_1_human" ],
    [ "HumanLandmark", "structfsdk_1_1_human_landmark.html", "structfsdk_1_1_human_landmark" ],
    [ "HumanLandmarks", "structfsdk_1_1_human_landmarks.html", "structfsdk_1_1_human_landmarks" ],
    [ "IAGSEstimator", "structfsdk_1_1_i_a_g_s_estimator.html", "structfsdk_1_1_i_a_g_s_estimator" ],
    [ "IArchive", "structfsdk_1_1_i_archive.html", "structfsdk_1_1_i_archive" ],
    [ "IAsyncContext", "structfsdk_1_1_i_async_context.html", "structfsdk_1_1_i_async_context" ],
    [ "IBestShotQualityEstimator", "structfsdk_1_1_i_best_shot_quality_estimator.html", "structfsdk_1_1_i_best_shot_quality_estimator" ],
    [ "IDataStorageObject", "structfsdk_1_1_i_data_storage_object.html", "structfsdk_1_1_i_data_storage_object" ],
    [ "IDenseIndex", "structfsdk_1_1_i_dense_index.html", null ],
    [ "IDescriptor", "structfsdk_1_1_i_descriptor.html", "structfsdk_1_1_i_descriptor" ],
    [ "IDescriptorBatch", "structfsdk_1_1_i_descriptor_batch.html", "structfsdk_1_1_i_descriptor_batch" ],
    [ "IDescriptorExtractor", "structfsdk_1_1_i_descriptor_extractor.html", "structfsdk_1_1_i_descriptor_extractor" ],
    [ "IDescriptorMatcher", "structfsdk_1_1_i_descriptor_matcher.html", "structfsdk_1_1_i_descriptor_matcher" ],
    [ "IDetectionComparer", "classfsdk_1_1_i_detection_comparer.html", "classfsdk_1_1_i_detection_comparer" ],
    [ "IDetector", "structfsdk_1_1_i_detector.html", "structfsdk_1_1_i_detector" ],
    [ "IDynamicDescriptorStorage", "structfsdk_1_1_i_dynamic_descriptor_storage.html", "structfsdk_1_1_i_dynamic_descriptor_storage" ],
    [ "IDynamicIndex", "structfsdk_1_1_i_dynamic_index.html", "structfsdk_1_1_i_dynamic_index" ],
    [ "IEyeEstimator", "structfsdk_1_1_i_eye_estimator.html", "structfsdk_1_1_i_eye_estimator" ],
    [ "IFaceEngineMobile", "structfsdk_1_1_i_face_engine_mobile.html", "structfsdk_1_1_i_face_engine_mobile" ],
    [ "IHeadPoseEstimator", "structfsdk_1_1_i_head_pose_estimator.html", "structfsdk_1_1_i_head_pose_estimator" ],
    [ "IHumanDetector", "structfsdk_1_1_i_human_detector.html", "structfsdk_1_1_i_human_detector" ],
    [ "IHumanWarper", "structfsdk_1_1_i_human_warper.html", "structfsdk_1_1_i_human_warper" ],
    [ "IIndex", "structfsdk_1_1_i_index.html", "structfsdk_1_1_i_index" ],
    [ "IIndexBuilder", "structfsdk_1_1_i_index_builder.html", "structfsdk_1_1_i_index_builder" ],
    [ "ILicense", "structfsdk_1_1_i_license.html", "structfsdk_1_1_i_license" ],
    [ "Image", "structfsdk_1_1_image.html", "structfsdk_1_1_image" ],
    [ "In_place_t", "structfsdk_1_1_in__place__t.html", "structfsdk_1_1_in__place__t" ],
    [ "IProgressTracker", "structfsdk_1_1_i_progress_tracker.html", "structfsdk_1_1_i_progress_tracker" ],
    [ "IRefCounted", "structfsdk_1_1_i_ref_counted.html", "structfsdk_1_1_i_ref_counted" ],
    [ "IResultBatch", "structfsdk_1_1_i_result_batch.html", "structfsdk_1_1_i_result_batch" ],
    [ "ISerializableObject", "structfsdk_1_1_i_serializable_object.html", "structfsdk_1_1_i_serializable_object" ],
    [ "ISettingsProvider", "structfsdk_1_1_i_settings_provider.html", "structfsdk_1_1_i_settings_provider" ],
    [ "IStaticDescriptorStorage", "structfsdk_1_1_i_static_descriptor_storage.html", "structfsdk_1_1_i_static_descriptor_storage" ],
    [ "IWarper", "structfsdk_1_1_i_warper.html", "structfsdk_1_1_i_warper" ],
    [ "Landmarks", "structfsdk_1_1_landmarks.html", "structfsdk_1_1_landmarks" ],
    [ "Landmarks5Indexes", "structfsdk_1_1_landmarks5_indexes.html", "structfsdk_1_1_landmarks5_indexes" ],
    [ "MatchingResult", "structfsdk_1_1_matching_result.html", "structfsdk_1_1_matching_result" ],
    [ "MultiError", "structfsdk_1_1_multi_error.html", "structfsdk_1_1_multi_error" ],
    [ "Noncopyable", "classfsdk_1_1_noncopyable.html", "classfsdk_1_1_noncopyable" ],
    [ "Optional", "classfsdk_1_1_optional.html", "classfsdk_1_1_optional" ],
    [ "Promise", "classfsdk_1_1_promise.html", "classfsdk_1_1_promise" ],
    [ "Ref", "structfsdk_1_1_ref.html", "structfsdk_1_1_ref" ],
    [ "RefBase", "structfsdk_1_1_ref_base.html", "structfsdk_1_1_ref_base" ],
    [ "Result", "structfsdk_1_1_result.html", "structfsdk_1_1_result" ],
    [ "ResultValue", "structfsdk_1_1_result_value.html", null ],
    [ "ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b.html", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b" ],
    [ "ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value==false >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8.html", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8" ],
    [ "SearchResult", "structfsdk_1_1_search_result.html", "structfsdk_1_1_search_result" ],
    [ "Sizer", "structfsdk_1_1_sizer.html", "structfsdk_1_1_sizer" ],
    [ "Span", "classfsdk_1_1_span.html", "classfsdk_1_1_span" ],
    [ "SubImage", "structfsdk_1_1_sub_image.html", "structfsdk_1_1_sub_image" ],
    [ "Transformation", "structfsdk_1_1_transformation.html", "structfsdk_1_1_transformation" ],
    [ "Vector2", "structfsdk_1_1_vector2.html", "structfsdk_1_1_vector2" ],
    [ "Version", "structfsdk_1_1_version.html", "structfsdk_1_1_version" ]
];

==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0/doc/fsdk/html/namespacefsdk.js <==
var namespacefsdk =
[
    [ "IAGSEstimator", "structfsdk_1_1_i_a_g_s_estimator.html", "structfsdk_1_1_i_a_g_s_estimator" ],
    [ "IBestShotQualityEstimator", "structfsdk_1_1_i_best_shot_quality_estimator.html", "structfsdk_1_1_i_best_shot_quality_estimator" ],
    [ "EyesEstimation", "structfsdk_1_1_eyes_estimation.html", "structfsdk_1_1_eyes_estimation" ],
    [ "EyeCropper", "structfsdk_1_1_eye_cropper.html", "structfsdk_1_1_eye_cropper" ],
    [ "IEyeEstimator", "structfsdk_1_1_i_eye_estimator.html", "structfsdk_1_1_i_eye_estimator" ],
    [ "HeadPoseEstimation", "structfsdk_1_1_head_pose_estimation.html", "structfsdk_1_1_head_pose_estimation" ],
    [ "IHeadPoseEstimator", "structfsdk_1_1_i_head_pose_estimator.html", "structfsdk_1_1_i_head_pose_estimator" ],
    [ "ErrorTraits< FSDKError >", "structfsdk_1_1_error_traits_3_01_f_s_d_k_error_01_4.html", null ],
    [ "IAsyncContext", "structfsdk_1_1_i_async_context.html", "structfsdk_1_1_i_async_context" ],
    [ "MatchingResult", "structfsdk_1_1_matching_result.html", "structfsdk_1_1_matching_result" ],
    [ "IDescriptor", "structfsdk_1_1_i_descriptor.html", "structfsdk_1_1_i_descriptor" ],
    [ "IDescriptorBatch", "structfsdk_1_1_i_descriptor_batch.html", "structfsdk_1_1_i_descriptor_batch" ],
    [ "ErrorTraits< IDescriptorBatch::Error >", "structfsdk_1_1_error_traits_3_01_i_descriptor_batch_1_1_error_01_4.html", null ],
    [ "IDescriptorExtractor", "structfsdk_1_1_i_descriptor_extractor.html", "structfsdk_1_1_i_descriptor_extractor" ],
    [ "IDescriptorMatcher", "structfsdk_1_1_i_descriptor_matcher.html", "structfsdk_1_1_i_descriptor_matcher" ],
    [ "IDetectionComparer", "classfsdk_1_1_i_detection_comparer.html", "classfsdk_1_1_i_detection_comparer" ],
    [ "FunctionDetectionComparer", "classfsdk_1_1_function_detection_comparer.html", "classfsdk_1_1_function_detection_comparer" ],
    [ "IDetector", "structfsdk_1_1_i_detector.html", "structfsdk_1_1_i_detector" ],
    [ "IFaceDetectionBatch", "structfsdk_1_1_i_face_detection_batch.html", "structfsdk_1_1_i_face_detection_batch" ],
    [ "IFaceEngineMobile", "structfsdk_1_1_i_face_engine_mobile.html", "structfsdk_1_1_i_face_engine_mobile" ],
    [ "IHumanDetectionBatch", "structfsdk_1_1_i_human_detection_batch.html", "structfsdk_1_1_i_human_detection_batch" ],
    [ "IHumanDetector", "structfsdk_1_1_i_human_detector.html", "structfsdk_1_1_i_human_detector" ],
    [ "IHumanWarper", "structfsdk_1_1_i_human_warper.html", "structfsdk_1_1_i_human_warper" ],
    [ "SearchResult", "structfsdk_1_1_search_result.html", "structfsdk_1_1_search_result" ],
    [ "IStaticDescriptorStorage", "structfsdk_1_1_i_static_descriptor_storage.html", "structfsdk_1_1_i_static_descriptor_storage" ],
    [ "IDynamicDescriptorStorage", "structfsdk_1_1_i_dynamic_descriptor_storage.html", "structfsdk_1_1_i_dynamic_descriptor_storage" ],
    [ "IIndex", "structfsdk_1_1_i_index.html", "structfsdk_1_1_i_index" ],
    [ "IDenseIndex", "structfsdk_1_1_i_dense_index.html", null ],
    [ "IDynamicIndex", "structfsdk_1_1_i_dynamic_index.html", "structfsdk_1_1_i_dynamic_index" ],
    [ "IProgressTracker", "structfsdk_1_1_i_progress_tracker.html", "structfsdk_1_1_i_progress_tracker" ],
    [ "IIndexBuilder", "structfsdk_1_1_i_index_builder.html", "structfsdk_1_1_i_index_builder" ],
    [ "ILicense", "structfsdk_1_1_i_license.html", "structfsdk_1_1_i_license" ],
    [ "IArchive", "structfsdk_1_1_i_archive.html", "structfsdk_1_1_i_archive" ],
    [ "ISerializableObject", "structfsdk_1_1_i_serializable_object.html", "structfsdk_1_1_i_serializable_object" ],
    [ "ErrorTraits< ISerializableObject::Error >", "structfsdk_1_1_error_traits_3_01_i_serializable_object_1_1_error_01_4.html", null ],
    [ "IDataStorageObject", "structfsdk_1_1_i_data_storage_object.html", "structfsdk_1_1_i_data_storage_object" ],
    [ "IRefCounted", "structfsdk_1_1_i_ref_counted.html", "structfsdk_1_1_i_ref_counted" ],
    [ "IResultBatch", "structfsdk_1_1_i_result_batch.html", "structfsdk_1_1_i_result_batch" ],
    [ "ISettingsProvider", "structfsdk_1_1_i_settings_provider.html", "structfsdk_1_1_i_settings_provider" ],
    [ "ErrorTraits< ISettingsProvider::Error >", "structfsdk_1_1_error_traits_3_01_i_settings_provider_1_1_error_01_4.html", null ],
    [ "Transformation", "structfsdk_1_1_transformation.html", "structfsdk_1_1_transformation" ],
    [ "IWarper", "structfsdk_1_1_i_warper.html", "structfsdk_1_1_i_warper" ],
    [ "LaunchOptions", "structfsdk_1_1_launch_options.html", "structfsdk_1_1_launch_options" ],
    [ "Detection", "structfsdk_1_1_detection.html", "structfsdk_1_1_detection" ],
    [ "Face", "structfsdk_1_1_face.html", "structfsdk_1_1_face" ],
    [ "Format", "structfsdk_1_1_format.html", "structfsdk_1_1_format" ],
    [ "Noncopyable", "classfsdk_1_1_noncopyable.html", "classfsdk_1_1_noncopyable" ],
    [ "Promise", "classfsdk_1_1_promise.html", "classfsdk_1_1_promise" ],
    [ "Future", "classfsdk_1_1_future.html", "classfsdk_1_1_future" ],
    [ "ErrorTraits< FutureError >", "structfsdk_1_1_error_traits_3_01_future_error_01_4.html", null ],
    [ "ErrorTraits< PromiseError >", "structfsdk_1_1_error_traits_3_01_promise_error_01_4.html", null ],
    [ "Human", "structfsdk_1_1_human.html", "structfsdk_1_1_human" ],
    [ "HumanLandmark", "structfsdk_1_1_human_landmark.html", "structfsdk_1_1_human_landmark" ],
    [ "HumanLandmarks", "structfsdk_1_1_human_landmarks.html", "structfsdk_1_1_human_landmarks" ],
    [ "Image", "structfsdk_1_1_image.html", "structfsdk_1_1_image" ],
    [ "ErrorTraits< Image::Error >", "structfsdk_1_1_error_traits_3_01_image_1_1_error_01_4.html", null ],
    [ "Landmarks", "structfsdk_1_1_landmarks.html", "structfsdk_1_1_landmarks" ],
    [ "Landmarks5Indexes", "structfsdk_1_1_landmarks5_indexes.html", "structfsdk_1_1_landmarks5_indexes" ],
    [ "MultiError", "structfsdk_1_1_multi_error.html", "structfsdk_1_1_multi_error" ],
    [ "ErrorTraits< MultiError< E0, E1 > >", "structfsdk_1_1_error_traits_3_01_multi_error_3_01_e0_00_01_e1_01_4_01_4.html", "structfsdk_1_1_error_traits_3_01_multi_error_3_01_e0_00_01_e1_01_4_01_4" ],
    [ "BaseRect", "structfsdk_1_1_base_rect.html", "structfsdk_1_1_base_rect" ],
    [ "Ref", "structfsdk_1_1_ref.html", "structfsdk_1_1_ref" ],
    [ "RefBase", "structfsdk_1_1_ref_base.html", "structfsdk_1_1_ref_base" ],
    [ "ErrorTraits", "structfsdk_1_1_error_traits.html", null ],
    [ "Result", "structfsdk_1_1_result.html", "structfsdk_1_1_result" ],
    [ "ResultValue", "structfsdk_1_1_result_value.html", null ],
    [ "ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b.html", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b" ],
    [ "ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value==false >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8.html", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8" ],
    [ "Sizer", "structfsdk_1_1_sizer.html", "structfsdk_1_1_sizer" ],
    [ "Span", "classfsdk_1_1_span.html", "classfsdk_1_1_span" ],
    [ "SubImage", "structfsdk_1_1_sub_image.html", "structfsdk_1_1_sub_image" ],
    [ "Vector2", "structfsdk_1_1_vector2.html", "structfsdk_1_1_vector2" ],
    [ "Version", "structfsdk_1_1_version.html", "structfsdk_1_1_version" ]
];
